﻿' _____________________________________

' L E G O   N X T   R E M O T E   C O N T R O L
'       2- Basic Moving With Error Handling
'                       Ron Kessler
'                      5/15/2013
' _____________________________________

' Purpose: This controls a Lego NXT via Bluetooth using Structured Error Handling & Helper Methods

' NOTES:
' Includes Try-Catch handler
'Includes a form_closing event for cleanup

' Updated 5/15/2013


Imports NKH.MindSqualls


Public Class frmMain

#Region "Class-Level Variables"
    ' ---our class-level variables
    Dim myBrick As NxtBrick                   'send messages to brick (CPU)
    Dim motorPair As NxtMotorSync         'this object keeps the motors turning at the same rate
    Dim PowerLevel As Byte = 75           'set power of motors to 75%

#End Region

    Private Sub btnConnect_Click(sender As Object, e As EventArgs) Handles bntConnect.Click
        Try

            Dim BlueToothPort As Byte = Byte.Parse(txtPort.Text.Trim())        'get the com port

            '---create new brick and tell it to use BlueTooth
            myBrick = New NxtBrick(NxtCommLinkType.Bluetooth, BlueToothPort)
            '---create two motors
            myBrick.MotorB = New NxtMotor()
            myBrick.MotorC = New NxtMotor()

            '---this creates a synch object that will drive motors straight
            motorPair = New NxtMotorSync(myBrick.MotorB, myBrick.MotorC)

            '---now connect
            myBrick.Connect()
            If (myBrick.IsConnected) Then
                grpMotors.Enabled = True

            Else
                grpMotors.Enabled = False
            End If

        Catch ex As Exception
            MessageBox.Show("Cannot connect to the robot. Please check bluetooth pairing.",
                "NXT Mover", MessageBoxButtons.OK, MessageBoxIcon.Error)
        End Try
    End Sub

    Private Sub btnForward_Click(sender As Object, e As EventArgs) Handles btnForward.Click
        Idle()
        motorPair.Run(Convert.ToSByte(PowerLevel), 0, 0)
    End Sub

    Private Sub btnLeft_Click(sender As Object, e As EventArgs) Handles btnLeft.Click
        Idle()
        myBrick.MotorB.Run(Convert.ToSByte(-PowerLevel / 2), 0)     'counterclockwise (powerlevel is negative)
        myBrick.MotorC.Run(Convert.ToSByte(PowerLevel / 2), 0)       'clockwise
    End Sub

    Private Sub btnRight_Click(sender As Object, e As EventArgs) Handles btnRight.Click
        Idle()
        myBrick.MotorB.Run(Convert.ToSByte(PowerLevel / 2), 0)
        myBrick.MotorC.Run(Convert.ToSByte(-PowerLevel / 2), 0)
    End Sub

    Private Sub btnReverse_Click(sender As Object, e As EventArgs) Handles btnReverse.Click
        Idle()
        motorPair.Run(Convert.ToSByte(-PowerLevel), 0, 0)
    End Sub

    Private Sub btnIdle_Click(sender As Object, e As EventArgs) Handles btnIdle.Click
        Idle()
    End Sub

#Region "Helper Methods"
    Private Sub Idle()

        '---stop motors and reset sensors
        motorPair.Idle()
        motorPair.ResetMotorPosition(True)

    End Sub

    Private Sub Disconnect()

        If Not myBrick Is Nothing And myBrick.IsConnected Then

            Idle()                                  '---stop motors before quitting
            myBrick.Disconnect()
            grpMotors.Enabled = False

        End If
    End Sub

#End Region



    Private Sub btnDisconnect_Click(sender As Object, e As EventArgs) Handles btnDisconnect.Click
        Disconnect()
    End Sub

    Private Sub btnExit_Click(sender As Object, e As EventArgs) Handles btnExit.Click
        Disconnect()
        Me.Close()
    End Sub

    Private Sub frmMain_FormClosing(sender As Object, e As FormClosingEventArgs) Handles MyBase.FormClosing
        Disconnect()

    End Sub
End Class
